@@ -9,15 +9,15 @@ def test_trankitner_english():
     model_class = model.construct().__class__
     assert model_class == TrankitNERParameters
     annotator = TrankitNERAnnotator()
-    parameters = TrankitNERParameters(lang="english")
+    parameters = TrankitNERParameters()
     docs: List[Document] = annotator.annotate(
         [
             Document(
                 text="Paris is the capital of France and Emmanuel Macron is the president of the French Republic.",
-                metadata=parameters.dict(),
+                metadata={'language': 'en'},
             )
         ],
-        parameters,
+        parameters
     )
     doc0 = docs[0]
     assert len(doc0.annotations) == 4
@@ -36,15 +36,15 @@ def test_trankitner_arabic():
     model_class = model.construct().__class__
     assert model_class == TrankitNERParameters
     annotator = TrankitNERAnnotator()
-    parameters = TrankitNERParameters(lang="arabic")
+    parameters = TrankitNERParameters()
     docs: List[Document] = annotator.annotate(
         [
             Document(
                 text="باريس هي عاصمة فرنسا وإيمانويل ماكرون هو رئيس الجمهورية الفرنسية",
-                metadata=parameters.dict(),
+                metadata={'language': 'ar'},
             )
         ],
-        parameters,
+        parameters
     )
     doc0 = docs[0]
     assert len(doc0.annotations) == 3
